@@ -1,24 +1,30 @@
 package HTTP::Engine;
 use 5.00800;
-use Shika;
-our $VERSION = '0.0.99_01';
+use Mouse;
+our $VERSION = '0.0.99_02';
 use HTTP::Engine::Request;
 use HTTP::Engine::Request::Upload;
 use HTTP::Engine::Response;
 use HTTP::Engine::Types::Core qw( Interface );
-use HTTP::Engine::Util;
 
 has 'interface' => (
     is      => 'ro',
-    isa => 'Interface',
+    isa => Interface,
     coerce  => 1,
     handles => [ qw(run) ],
 );
 
+no Mouse;
+$_->meta->make_immutable(inline_destructor => 1) for qw(
+    HTTP::Engine::Request::Upload
+    HTTP::Engine::Request
+    HTTP::Engine::Response
+    HTTP::Engine
+);
 1;
 __END__
 
-=for stopwords middlewares Middleware middleware nothingmuch kan Stosberg
+=for stopwords middlewares Middleware middleware nothingmuch kan Stosberg otsune
 
 =encoding utf8
 
@@ -231,11 +237,13 @@ kawa0117
 
 mattn
 
+otsune
+
 =head1 SEE ALSO
 
 L<HTTP::Engine::Compat>,
 L<HTTPEx::Declare>,
-L<Shika>
+L<Mouse>
 
 =head1 REPOSITORY
 
