@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 package HTTP::Engine::Role::RequestBuilder::ReadBody;
-use Shika::Role;
+use Mouse::Role;
 use Carp ();
 
 requires "_handle_read_chunk";
@@ -95,7 +95,7 @@ sub _io_read {
     return $handle->read(@_);
 }
 
-__PACKAGE__
+1;
 
 __END__
 
