@@ -1,15 +1,15 @@
 package HTTP::Engine::Role::RequestBuilder::Standard;
-use Shika::Role;
+use Mouse::Role;
 
 use Socket qw[AF_INET inet_aton];
 
 with qw(HTTP::Engine::Role::RequestBuilder);
+use CGI::Simple::Cookie ();
 
 sub _build_cookies {
     my($self, $req) = @_;
 
     if (my $header = $req->header('Cookie')) {
-        HTTP::Engine::Util::require_once('CGI/Simple/Cookie.pm');
         return { CGI::Simple::Cookie->parse($header) };
     } else {
         return {};
